@@ -47,12 +47,7 @@ classifiers = [
     "Programming Language :: Python",
     ]
 
-install_requires = [
-    # -*- Install requires: -*-
-    'setuptools',
-    'decorator',
-    'argparse',
-    ]
+install_requires = open("requirements.txt").read().split('\n')
 
 # compatible with distutils of python 2.3+ or later
 setup(
@@ -61,7 +56,7 @@ setup(
     description=DESCRIPTION,
     long_description=open('README.rst', 'r').read(),
     classifiers=classifiers,
-    keywords='subprocess interface',
+    keywords='argparse decorator optparse signature command-line',
     author='ponty',
     #author_email='',
     url=URL,
@@ -97,10 +92,18 @@ if ALL_TASKS_LOADED:
                                      ]
     
     options.paved.dist.manifest.include.remove('distribute_setup.py')
+    options.paved.dist.manifest.include.add('requirements.txt')
     
     
     @task
-    @needs('sloccount', 'html', 'pdf', 'sdist', 'nose')
+    @needs(
+           'clean',
+           'sloccount', 
+           'html', 
+           'pdf', 
+           'sdist', 
+           'nose',
+           )
     def alltest():
         'all tasks to check'
         pass
@@ -117,3 +120,41 @@ if ALL_TASKS_LOADED:
         d=path('docs/_build/html')
         d.makedirs()
         fpdf.copy(d)
+
+
+    def install_test(installer):
+        import virtualenv
+        import tempfile
+        import textwrap
+        root = path(tempfile.mkdtemp(prefix=NAME + '_'))
+        info( 'root='+ root)
+        script = root / 'start_virtualenv'
+        
+        txt = """
+        def after_install(options, home_dir):
+            assert not os.system('{installer} {NAME}')
+        """.format(
+                   NAME=NAME,
+                   installer=root / 'env' / 'bin' / installer,
+                   )
+        
+        script_text = virtualenv.create_bootstrap_script(textwrap.dedent(txt))
+        script.write_text(script_text)
+        script.chmod(0755)
+        sh('./start_virtualenv env --no-site-packages', cwd=root)
+
+    @task
+    def pypi_pip():
+        install_test('pip install')
+
+    @task
+    def pypi_easy_install():
+        install_test('easy_install')
+        
+    @task
+    @needs(
+           'pypi_easy_install',
+           'pypi_pip', 
+           )
+    def pypi():
+        pass
